@@ -20,8 +20,8 @@ class Parser:
     def get_current_url(self) -> str:
         return self.scraper.get_current_url()
 
-    def enter_text(self, path: str, text: str, clear: bool=False, element: any=None):
-        return self.scraper.enter_text(path=path, text=text, clear=clear, element=element)
+    def enter_text(self, path: str, text: str, clear: bool=False, element: any=None, timeout: int=0):
+        return self.scraper.enter_text(path=path, text=text, clear=clear, element=element, timeout=timeout)
 
     def wget(self, url: str, tries: int=0):
         return self.scraper.wget(url, tries)
