@@ -19,16 +19,18 @@ import base64
 
 class Selenium(Scraper):
 
-    def __init__(self, headless=True):
+    def __init__(self, headless: bool=True, size: list=[]):
         options = webdriver.ChromeOptions()
         
         options.add_argument('--no-sandbox')
         options.add_argument('--log-level=3')
-        options.add_argument('start-maximized')
         options.add_argument('disable-infobars')
         options.add_argument('--disable-extensions')
         options.add_argument('--disable-dev-shm-usage')
 
+        if len(size) == 0:
+            options.add_argument('start-maximized')
+
         if headless is True:
             options.add_argument('headless')
 
@@ -39,7 +41,9 @@ class Selenium(Scraper):
         if platform.system() == 'Linux':
             self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
         
-        self.handles = {}
+        if len(size) > 0:
+            self.driver.set_window_position(x=0, y=0)
+            self.driver.set_window_size(width=size[0], height=size[1])
 
         super().__init__()
 
@@ -59,8 +63,6 @@ class Selenium(Scraper):
         except NoSuchElementException:
             return None
 
-        return element
-
     def on_exists(self, path, element, timeout=0):
         element = self.driver if element is None else element
 
